@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
+"""Contains base exception"""
 
 
 class BasePyPDFFormException(Exception):
     """Base exception for PyPDFForm."""
-
-    pass
